<?hh
/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

// @oss-enable: use namespace FlibSL\{C, Math, Str, Vec};

/**
 * Compact Protocol Factory
 */
<<Oncalls('thrift')>> // @oss-disable
final class TCompactProtocolFactory implements TProtocolFactory {

  public function __construct() {}

  public function getProtocol(TTransport $trans)[]: TProtocol {
    return new TCompactProtocolAccelerated(
      $trans is IThriftBufferedTransport
        ? $trans
        : new TBufferedTransport<TTransport>($trans),
    );
  }
}
